# Wobbly Balls
# Copyright (C) 2010 Jeffrey Armstrong <jeff@rainbow-100.com>
# http://jeff.rainbow-100.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# A full version of the license terms is available in LICENSE.

import random
import pygame
import data
from constants import *

class Level:
    def __init__(self, blocks, weights, strengths, duration):
        self.blocks = blocks
        self.weights = weights
        self.strengths = strengths
        #self.windrops = drops
        self.drops = 0
        self.duration = duration
        self.start = None
        self.remains = 60
        
    def strength(self):
        return random.randint(self.strengths[0],self.strengths[1])
        
    def weight(self):
        return random.randint(self.weights[0],self.weights[1])
        
    def win(self):
        #return self.drops > self.windrops
        if self.start == None:
            self.start = pygame.time.get_ticks()
            
        self.remains = self.duration - (pygame.time.get_ticks() - self.start)/1000.0
        
        if self.remains <= 0:
            return True
        else:
            return False
        
    def drop(self):
        self.drops = self.drops + 1
        
        
        
def build_levels():
    levels = [ Level(3, (5,5), (50,50), 30), \
               Level(3, (5,9), (50,50), 45), \
               Level(3, (4,9), (20,50), 50), \
               Level(4, (3,3), (50,50), 45), \
               Level(4, (3,5), (20,50), 45), \
               Level(4, (2,9), (20,50), 30), \
               Level(4, (2,14), (20,50), 45), \
               Level(5, (3,3), (50,50), 45), \
               Level(5, (2,7), (20,50), 60), \
               Level(5, (2,10), (5,75), 1E+9) ]
               
    return levels

def total_drops(levels):
    ret = 0
    for l in levels:
        ret = ret + l.drops
    return ret

class LevelAnnounce(pygame.sprite.Sprite):
    def __init__(self,levelnum):
        pygame.sprite.Sprite.__init__(self)
        
        font = pygame.font.Font(data.filepath(SCORE_FONT_NAME),SCORE_FONT_SIZE)
                
        number = font.render(str(levelnum),1,pygame.Color(255,255,255,255))
            
        self.base_image = pygame.Surface((number.get_width(),number.get_height()))
        self.base_image.fill(pygame.Color(0,0,0,0))
        self.base_image.set_colorkey(pygame.Color(0,0,0,0))
        self.base_image.blit(number, (0,0))

        self.rect = self.base_image.get_rect()
        
        self.rect.center = (SCREEN_X/2,SCREEN_Y/2)
        
        self.start = float(pygame.time.get_ticks())
        self.done = False
    
    def update(self):
        
        passed = float(pygame.time.get_ticks())-self.start
        
        fraction = passed/float(LEVEL_CHANGE_TIME)
        
        alpha = int(min(255.0,255.0*(1.0-fraction)))
        if alpha < 0 or passed > LEVEL_CHANGE_TIME:
            self.done = True
            alpha = 0
        
        self.image = self.base_image.convert()
        scaler = 1.0+fraction*LEVEL_CHANGE_ZOOM
        w = int(scaler*self.base_image.get_rect().width)
        h = int(scaler*self.base_image.get_rect().height)
        self.image = pygame.transform.scale(self.image,(w,h))
        self.image.set_alpha(alpha)

        self.rect = self.image.get_rect()
        self.rect.center = (SCREEN_X/2,SCREEN_Y/2)
