# Wobbly Balls
# Copyright (C) 2010 Jeffrey Armstrong <jeff@rainbow-100.com>
# http://jeff.rainbow-100.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# A full version of the license terms is available in LICENSE.

import pygame
import data
from constants import *

class ScoreBoard(pygame.sprite.Sprite):
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        
        self.drops = 0
        self.time = 0
        self.level = None
        
        self.font = pygame.font.Font(data.filepath(SCORE_FONT_NAME),SCORE_FONT_SIZE)
        self.brag_font = pygame.font.Font(data.filepath(SCORE_FONT_NAME),BRAG_FONT_SIZE)
        
        self.rect = pygame.Rect(0,0,SCREEN_X,SCORE_HEIGHT) 
        
    def update(self):
        self.image = pygame.Surface((self.rect.width,self.rect.height))
        self.image.convert()
        self.image.set_colorkey(pygame.Color(SCORE_COLOR[0],SCORE_COLOR[1],SCORE_COLOR[2],255))
        self.image.fill(pygame.Color(SCORE_COLOR[0],SCORE_COLOR[1],SCORE_COLOR[2],255))
        
        render_brag = self.brag_font.render('Wobbly Balls! by PrintStar',1,pygame.Color(0,0,255,255))
        self.image.blit(render_brag,(10,10))
        
        if self.level == None:
            return
        
        render_drops = self.font.render('Drops: %d' % (self.drops,),1,pygame.Color(0,0,255,255))
        self.image.blit(render_drops,(10,40))
        
        if self.level.remains < 600:
            render_time = self.font.render('Time: %d sec' % (self.level.remains,),1,pygame.Color(0,0,255,255))
            self.image.blit(render_time,(self.rect.right - render_time.get_width() - 10,40))
        
class InfoBoard(pygame.sprite.Sprite):
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.playgroup = None
        self.start = 0
        self.end = None
        
        h = int((BLOCK_Y+2)*6.5)
        self.rect = pygame.Rect(10,SCREEN_Y-h-10,90,h)
        
        self.font = pygame.font.Font(data.filepath(INFO_FONT_NAME),INFO_FONT_SIZE)
        
    def set_playgroup(self,playgroup):
        if self.playgroup:
            self.end = pygame.time.get_ticks()
            self.start = None
        else:
            self.start = 0
        
        self.playgroup = playgroup

    def update(self):
        alpha = 255
        if self.end:
            fraction = pygame.time.get_ticks() - self.end
            fraction = float(fraction)/float(INFO_ALPHA_TIME)
            alpha = int(min(255,(1.0-fraction)*float(alpha)))
            if alpha <= 0:
                self.end = None
                self.start = 0
                
        if self.start == 0:
            self.start = pygame.time.get_ticks()
            self.build_image()
            
        if self.start > 0:
            fraction = pygame.time.get_ticks() - self.start
            fraction = float(fraction)/float(INFO_ALPHA_TIME)
            alpha = int(min(255,fraction*float(alpha)))

        if self.playgroup == None:
            alpha = 0

        self.image.set_alpha(alpha)
                    
    def render_text_line(self,line,entries,image=None):
        render_head1 = self.font.render(entries[0],1,pygame.Color(0,0,0,255))
        render_head2 = self.font.render(entries[1],1,pygame.Color(0,0,0,255))
        
        self.image.blit(render_head1,(30,line*(BLOCK_Y+2)+2))
        self.image.blit(render_head2,(60,line*(BLOCK_Y+2)+2))
        if image:
            self.image.blit(image,(5,line*(BLOCK_Y+2)+6))
        
    def build_image(self):
        self.image = pygame.Surface((self.rect.width,self.rect.height))
        self.image.convert()
        
        self.image.fill(pygame.Color(255,255,255,255))
        
        self.render_text_line(0, ('W','S'))
        
        if self.playgroup:
            if self.playgroup.blocks:
                i = 1
                for b in self.playgroup.blocks:
                    self.render_text_line(i, (str(b.weight),str(b.strength)), b.image)
                    i = i + 1
        
                     
        
        
